/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaweb.vehiclerouting.plugin.websocket;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.ApplicationListener;
import org.springframework.stereotype.Component;
import org.springframework.web.socket.messaging.AbstractSubProtocolEvent;
import org.springframework.web.socket.messaging.SessionConnectEvent;
import org.springframework.web.socket.messaging.SessionSubscribeEvent;

/**
 * Logs WebSocket events, such as {@link SessionConnectEvent} and {@link SessionSubscribeEvent}, on DEBUG level.
 */
@Component
class WebSocketEventLogger implements ApplicationListener<AbstractSubProtocolEvent> {

    private static final Logger logger = LoggerFactory.getLogger(WebSocketEventLogger.class);

    @Override
    public void onApplicationEvent(AbstractSubProtocolEvent event) {
        logger.debug("{}", event);
    }
}
